License and Distribution
=======================================

License
+++++++++++++++++++++++++++++++++++++

``fwdpp`` is distributed under the terms of the GNU Public License, version 3 or later.
This is also referred to as ``GPL3+``.

The license file is available with the source code via the files ``LICENSE`` and ``COPYING``.

Distribution
+++++++++++++++++++++++++++++++++++++

``fwdpp`` can be obtained via `GitHub <https://github.com/molpopgen/fwdpp>`_.

Build status
+++++++++++++++++++++++++++++++++++++

Main branch:

.. image:: https://circleci.com/gh/molpopgen/fwdpp.svg?style=svg
    :target: https://circleci.com/gh/molpopgen/fwdpp/tree/main

Development branch:

.. image:: https://circleci.com/gh/molpopgen/fwdpp.svg?style=svg
    :target: https://circleci.com/gh/molpopgen/fwdpp/tree/dev

